/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export default {
  home: '首页',
  project: '项目管理',
  resources: '资源中心',
  datasource: '源中心',
  monitor: '监控中心',
  security: '安全中心',
  ui_setting: '界面设置',
  project_overview: '项目概览',
  project_parameter: '项目级别参数',
  project_preferences: '项目偏好设置',
  workflow_relation: '工作流关系',
  workflow: '工作流',
  workflow_definition: '工作流定义',
  workflow_instance: '工作流实例',
  workflow_timing: '工作流定时',
  task: '任务',
  task_instance: '任务实例',
  task_definition: '任务定义',
  file_manage: '文件管理',
  udf_manage: 'UDF管理',
  resource_manage: '资源管理',
  function_manage: '函数管理',
  service_manage: '服务管理',
  master: 'Master',
  worker: 'Worker',
  db: 'DB',
  statistical_manage: '统计管理',
  statistics: 'Statistics',
  audit_log: '审计日志',
  tenant_manage: '租户管理',
  user_manage: '用户管理',
  alarm_group_manage: '告警组管理',
  alarm_instance_manage: '告警实例管理',
  worker_group_manage: 'Worker分组管理',
  yarn_queue_manage: 'Yarn队列管理',
  environment_manage: '环境管理',
  cluster_manage: '集群管理',
  k8s_namespace_manage: 'K8S命名空间管理',
  token_manage: '令牌管理',
  task_group_manage: '任务组管理',
  task_group_option: '任务组配置',
  task_group_queue: '任务组队列',
  data_quality: '数据质量',
  task_result: '任务结果',
  rule: '规则管理'
}
